@@ -14,7 +14,7 @@ use DBIx::Class::Async::TxnGuard;
 use DBIx::Class::Async::ResultSet;
 use DBIx::Class::Async::Storage::DBI;
 
-our $VERSION = '0.35';
+our $VERSION = '0.36';
 
 =head1 NAME
 
@@ -22,7 +22,7 @@ DBIx::Class::Async::Schema - Asynchronous schema for DBIx::Class::Async
 
 =head1 VERSION
 
-Version 0.35
+Version 0.36
 
 =cut
 
@@ -347,17 +347,17 @@ error message generated by the worker.
 sub deploy {
     my ($self, $sqlt_args, $dir) = @_;
 
-    return $self->{async_db}
-                ->deploy($sqlt_args, $dir)
-                ->then(sub {
-                    my ($res) = @_;
+    croak "Async database handle not initialised" unless $self->{async_db};
 
-                    if (ref $res eq 'HASH' && $res->{__error}) {
-                        return Future->fail($res->{__error});
-                    }
+    return $self->{async_db}->deploy($sqlt_args, $dir)->then(sub {
+        my ($res) = @_;
 
-                    return Future->done($self);
-                });
+        if (ref $res eq 'HASH' && $res->{__error}) {
+            return Future->fail($res->{__error});
+        }
+
+        return Future->done($self);
+    });
 }
 
 =head2 disconnect
@@ -740,6 +740,25 @@ sub storage {
     return $self->{_storage};
 }
 
+=head2 txn_batch
+
+    my $result = await $schema->txn_batch(@operations);
+
+A proxy method for L<DBIx::Class::Async/txn_batch>. Executes a series of
+database operations (create, update, delete, or raw SQL) atomically
+within a single background transaction.
+
+=cut
+
+sub txn_batch {
+    my ($self, @args) = @_;
+
+    croak "Async database handle not initialised in schema."
+        unless $self->{async_db};
+
+    return $self->{async_db}->txn_batch(@args);
+}
+
 =head2 txn_do
 
     $schema->txn_do(sub {
